@@ -19,12 +19,16 @@ class Tile(object):
         self.booth = None
         self.update_threshold()
 
+        self.visible = True
+
     def __str__(self):
         return "({}, {})".format(len(self.bots), len(self.bots_in_line))
 
     def __repr__(self):
         if not self.booth == None:
             return "BOOTH"
+        if not self.visible:
+            return "TXXXX"
         if self.end_of_line:
             return "E%02d%02d" % (len(self.bots), len(self.bots_in_line))
         if not self.line == None:
@@ -33,6 +37,9 @@ class Tile(object):
         #return "({}, {})".format(len(self.bots), len(self.bots_in_line))
 
     # Getters that are available to players.
+    def is_visible(self):
+        return self.visible
+
     def get_line(self):
         """
         If this tile is part of a line, returns the name of the company
@@ -138,6 +145,8 @@ class Tile(object):
         new_tile.end_of_line = self.end_of_line
         new_tile.update_threshold()
 
+        new_tile.visible = self.visible
+
         return new_tile
 
 class Booth(object):
@@ -247,6 +256,8 @@ class Line(object):
                 tile.update_line(line)
                 if not end:
                     tile.set_end_of_line(True)
+                else:
+                    tile.set_end_of_line(False)
             else:
                 mini_line = line[:self.max_per_tile]
                 line = line[self.max_per_tile:]
